Django MetaAuth Documentation
============================

Django MetaAuth is a reusable Django app for Meta (Facebook) API authentication.

Contents
--------

.. toctree::
   :maxdepth: 2
   
   installation
   configuration
   usage
   api
   
Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search` 